Changelog
=========

0.0.2 (2022-05-07)
------------------


0.0.1 (2022-05-06)
---------------------------------------

| Initialized **Project** from a `Cookiecutter Template`
| Template at https://github.com/boromir674/cookiecutter-python-package/tree/master/src/cookiecutter_python
